@@ -221,14 +221,7 @@ getClusters=function(surf_data,edgelist)
   vert=which(surf_data!=0)
   
   #matching non-zero vertices with adjacency matrices to obtain list of edges connecting between the non-zero vertices
-  edgelist0=edgelist[!is.na(match(edgelist[,1],vert)),]
-  if(length(edgelist0)>2)  {edgelist1=edgelist0[!is.na(match(edgelist0[,2],vert)),]} 
-  else if (length(edgelist0)==2)  ##if only a single edge was identified, edgelist will no longer be a Nx2 matrix, hence need to reshape it into a matrix
-  { 
-    edgelist0=matrix(edgelist0,ncol=2,nrow=1)
-    edgelist1=edgelist0[!is.na(match(edgelist0[,2],vert)),]
-  } else {edgelist1=0}
-  remove(surf_data,vert,edgelist0)
+  edgelist1 = edgelist[rowSums(matrix(edgelist %in% vert,ncol=2)) == 2, , drop = FALSE]
   
   if(length(edgelist1)>2) #if at least 2 edges are identified
   {
@@ -1060,4 +1053,4 @@ get_surf_obj=function(surf_data)
 
   return(surf_data)
 }
- 
\ No newline at end of file
+ 
